@@ -52,9 +52,6 @@
 //C- | TO ANY WARRANTY OF NON-INFRINGEMENT, OR ANY IMPLIED WARRANTY OF
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
-// 
-// $Id: djvm.cpp,v 1.12 2007/03/25 20:48:35 leonb Exp $
-// $Name: release_3_5_20_2 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -128,8 +125,7 @@
     DjVu multipage documents creator.
     @author
     Andrei Erofeev <eaf@geocities.com>
-    @version
-    #$Id: djvm.cpp,v 1.12 2007/03/25 20:48:35 leonb Exp $# */
+*/
 //@{
 //@}
 
@@ -139,9 +135,9 @@
 #include "DjVuMessage.h"
 
 #include <locale.h>
+#include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <stdlib.h>
 
 static const char * progname;
 
@@ -301,6 +297,7 @@ int
 main(int argc, char ** argv)
 {
   setlocale(LC_ALL,"");
+  setlocale(LC_NUMERIC,"C");
   djvu_programname(argv[0]);
   GArray<GUTF8String> dargv(0,argc-1);
   for(int i=0;i<argc;++i)
