@@ -52,9 +52,6 @@
 //C- | TO ANY WARRANTY OF NON-INFRINGEMENT, OR ANY IMPLIED WARRANTY OF
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
-// 
-// $Id: djvudump.cpp,v 1.8 2007/03/25 20:48:35 leonb Exp $
-// $Name: release_3_5_22 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -107,8 +104,7 @@
 xxx
     @author
     L\'eon Bottou <leonb@research.att.com>
-    @version
-    #$Id: djvudump.cpp,v 1.8 2007/03/25 20:48:35 leonb Exp $# */
+*/
 //@{
 //@}
 
@@ -116,26 +112,35 @@ xxx
 #include "ByteStream.h"
 #include "GException.h"
 #include "GOS.h"
+#include "GString.h"
 #include "GURL.h"
 #include "DjVuMessage.h"
 
 #include <locale.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <stddef.h>
 #include <stdlib.h>
 
+const char *outputfile = 0;
+FILE *outputf = stdout;
+
 void
 display(const GURL &url)
 {
    DjVuDumpHelper helper;
-   GP<ByteStream> ibs=ByteStream::create(url, "rb");
-   GP<ByteStream> str_out;
-   str_out=helper.dump(ibs);
-   GP<ByteStream> obs=ByteStream::create("w");
-   str_out->seek(0);
-   obs->copy(*str_out);
+   GP<ByteStream> ibs = ByteStream::create(url, "rb");
+   GP<ByteStream> obs = helper.dump(ibs);
+   GUTF8String str;
+   size_t size = obs->size();
+   char *buf = str.getbuf(obs->size());
+   obs->seek(0);
+   obs->readall(buf, size);
+   GNativeString ns = str;
+   fputs((const char*)ns, outputf);
 }
 
+
 void
 usage()
 {
@@ -144,7 +149,7 @@ usage()
           "DJVUDUMP --- DjVuLibre-" DJVULIBRE_VERSION "\n"
 #endif
           "Describes DjVu and IFF85 files\n\n"
-          "Usage: djvudump <iff_filenames>\n" );
+          "Usage: djvudump [-o outputfile] <iff_filenames>\n" );
   exit(1);
 }
 
@@ -152,25 +157,39 @@ int
 main(int argc, char **argv)
 {
   setlocale(LC_ALL,"");
+  setlocale(LC_NUMERIC,"C");
   djvu_programname(argv[0]);
-  GArray<GUTF8String> dargv(0,argc-1);
+  // get output file name
+  if (argc>2 && !strcmp(argv[1],"-o"))
+    {
+      outputfile = argv[2];
+      argv += 2;
+      argc -= 2;
+    }
+  // convert iff file name
+  GArray<GUTF8String> dargv(0, argc-1);
   for(int i=0;i<argc;++i)
     dargv[i]=GNativeString(argv[i]);
-  G_TRY
+  if (argc <= 1)
+    usage();
+  if (outputfile && !(outputf = fopen(outputfile,"w")))
     {
-      if (argc<=1)
-        usage();
-      for (int i=1; i<argc; i++)
-      {
-        const GURL::Filename::UTF8 url(dargv[i]);
-        display(url);
-      }
-    }
-  G_CATCH(ex)
-    {
-      ex.perror();
+      DjVuPrintErrorUTF8("djvudump: Cannot open output file.\n");
       exit(1);
     }
+  G_TRY
+    {
+      for (int i=1; i<argc; i++)
+        {
+        const GURL::Filename::UTF8 url(dargv[i]);
+        display(url);
+        }
+    }
+  G_CATCH(ex)
+  {
+      ex.perror();
+      exit(1);
+  }
   G_ENDCATCH;
   return 0;
 }
