@@ -52,8 +52,6 @@
 //C- | TO ANY WARRANTY OF NON-INFRINGEMENT, OR ANY IMPLIED WARRANTY OF
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
-// 
-// $Id: djvutxt.cpp,v 1.15 2007/04/20 15:22:43 leonb Exp $
 
 
 /* Program djvutxt has been rewritten to use the ddjvuapi only.
@@ -63,6 +61,7 @@
 # include "config.h"
 #endif
 
+#include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -143,9 +142,13 @@ dopage(int pageno)
   const char *lvl = (detail) ? detail : "page";
   while ((r = ddjvu_document_get_pagetext(doc,pageno-1,lvl))==miniexp_dummy)
     handle(TRUE);
-  minilisp_print_7bits = escape;
   if (detail)
-    miniexp_pprint(r, 72);
+    {
+      miniexp_io_t io;
+      miniexp_io_init(&io);
+      io.p_print7bits = &escape;
+      miniexp_pprint_r(&io, r, 72);
+    }
   else if ((r = miniexp_nth(5, r)) && miniexp_stringp(r))
     {
       const char *s = miniexp_to_str(r); 
@@ -175,7 +178,7 @@ dopage(int pageno)
 void
 parse_pagespec(const char *s, int max_page, void (*dopage)(int))
 {
-  static char *err = I18N("invalid page specification: %s");
+  static const char *err = I18N("invalid page specification: %s");
   int spec = 0;
   int both = 1;
   int start_page = 1;
